-----------------------------------------------------------------------------

local L = AceLibrary("AceLocale-2.2"):new("Aloft")
local SML = AceLibrary("SharedMedia-1.0")
local SML_font = SML:List("font")
local SML_statusbar = SML:List("statusbar")

-----------------------------------------------------------------------------

Aloft.OnMenuRequest = 
{
	handler = Aloft,
	type = 'group',
	args = 
	{
		show =
		{
			type = 'toggle',
			name = L["Show Nameplates"],
			desc = L["Show nameplates for neutral or hostile units"],
			get = function() return NAMEPLATES_ON end,
			set = function(v) if v then ShowNameplates() else HideNameplates() end NAMEPLATES_ON = v end,
			order = 1
		},
		showFriendly =
		{
			type = 'toggle',
			name = L["Show Friendly Nameplates"],
			desc = L["Show nameplates for friendly units"],
			get = function() return FRIENDNAMEPLATES_ON end,
			set = function(v) if v then ShowFriendNameplates() else HideFriendNameplates() end FRIENDNAMEPLATES_ON = v end,
			order = 2
		},
		reportStatusChanges =
		{
			type = 'toggle',
			name = L["Report Status Changes"],
			desc = L["Prints the status of nameplates whenever they change"],
			get = function() return Aloft.db.profile.reportStatusChanges end,
			set = function(v) Aloft.db.profile.reportStatusChanges = v end,
			order = 3
		},
		spacer = 
		{
			type = 'header',
			order = 4,
		},
	
		nameText =
		{
			type = 'group',
			name = L["Name Text"],
			desc = L["Nameplate text options"],
			args =
			{
				visible =
				{
					type = 'toggle',
					name = L["Enable"],
					desc = L["Show unit names"],
					get = function() return Aloft.db.profile.nameplateText.visible end,
					set = function(v) Aloft.db.profile.nameplateText.visible = v Aloft:UpdateNameplateText() end
				},
				font =
				{
					type = "text", 
					name = L["Font"], 
					desc = L["Sets the font for nameplate text"],
					get = function() return Aloft.db.profile.nameplateText.font end,
					set = function(v) Aloft.db.profile.nameplateText.font = v Aloft:UpdateNameplateText() end,
					validate = SML_font,
				},
				fontSize =
				{
					type = 'range',
					name = L["Font Size"],
					desc = L["Sets the font height of the nameplate text"],
					max = 16,
					min = 4,
					step = 1,
					get = function() return Aloft.db.profile.nameplateText.fontSize end,
					set = function(value) Aloft.db.profile.nameplateText.fontSize = value Aloft:UpdateNameplateText() end
				},
				shadow =
				{
					type = 'toggle',
					name = L["Font Shadow"],
					desc = L["Show font shadow on nameplate text"],
					get = function() return Aloft.db.profile.nameplateText.shadow end,
					set = function(v) Aloft.db.profile.nameplateText.shadow = v Aloft:UpdateNameplateText() end
				},
				alignment =
				{
					type = 'text',
					name = L["Alignment"],
					desc = L["Sets the alignment of the nameplate text"],
					get = function() return Aloft.db.profile.nameplateText.alignment end,
					set = function(value) Aloft.db.profile.nameplateText.alignment = value Aloft:UpdateNameplateText() end,
					validate = {"LEFT", "CENTER", "RIGHT" },
				},
				outline =
				{
					type = 'text',
					name = L["Outline"],
					desc = L["Sets the font outline for nameplate text"],
					get = function() return Aloft.db.profile.nameplateText.outline end,
					set = function(value) Aloft.db.profile.nameplateText.outline = value Aloft:UpdateNameplateText() end,
					validate = {"None", "Normal", "Thick" },
				},
				position =
				{
					type = 'group',
					name = L["Position"],
					desc = L["Adjust nameplate text position"],
					args =
					{
						left =
						{
							type = 'range',
							name = L["Left Offset"],
							desc = L["Sets the offset of the left of the text"],
							min = -100,
							max = 100,
							step = 1,
							get = function() return Aloft.db.profile.nameplateText.offsets.left end,
							set = function(v) Aloft.db.profile.nameplateText.offsets.left = v Aloft:UpdateNameplateText() end
						},
						right =
						{
							type = 'range',
							name = L["Right Offset"],
							desc = L["Sets the offset of the right of the text"],
							min = -100,
							max = 100,
							step = 1,
							get = function() return Aloft.db.profile.nameplateText.offsets.right end,
							set = function(v) Aloft.db.profile.nameplateText.offsets.right = v Aloft:UpdateNameplateText() end
						},
						vertical =
						{
							type = 'range',
							name = L["Vertical Offset"],
							desc = L["Sets the vertical offset of the text"],
							min = -64,
							max = 64,
							step = 1,
							get = function() return Aloft.db.profile.nameplateText.offsets.vertical end,
							set = function(v) Aloft.db.profile.nameplateText.offsets.vertical = v Aloft:UpdateNameplateText() end
						},
					},
				},
				overrideColors =
				{
					type = 'toggle',
					name = L["Override Colors"],
					desc = L["Override the games colors for nameplate text"],
					get = function() return Aloft.db.profile.nameplateText.overrideColors end,
					set = function(value) Aloft.db.profile.nameplateText.overrideColors = value Aloft:UpdateNameplateText() end,
				},
				colors =
				{
					type = 'group',
					name = L["Colors"],
					desc = L["Customize colors"],
					disabled = function() return not Aloft.db.profile.nameplateText.overrideColors end,
					args =
					{
						friendlyPlayer =
						{
							type = 'color',
							name = L["Friendly Players"],
							desc = L["Sets the nameplate color for friendly players"],
							get = function() return unpack(Aloft.db.profile.nameplateText.colors.friendlyPlayer) end,
							set = function(r, g, b) Aloft.db.profile.nameplateText.colors.friendlyPlayer = { r, g, b } Aloft:UpdateNameplateText() end,
						},
						friendlyNPC =
						{
							type = 'color',
							name = L["Friendly NPCs"],
							desc = L["Sets the nameplate bar color for friendly NPCs"],
							get = function() return unpack(Aloft.db.profile.nameplateText.colors.friendlyNPC) end,
							set = function(r, g, b) Aloft.db.profile.nameplateText.colors.friendlyNPC = { r, g, b } Aloft:UpdateNameplateText() end,
						},
						friendlyBoss =
						{
							type = 'color',
							name = L["Friendly Boss"],
							desc = L["Sets the nameplate color for friendly NPC Bosses"],
							get = function() return unpack(Aloft.db.profile.nameplateText.colors.friendlyBoss) end,
							set = function(r, g, b) Aloft.db.profile.nameplateText.colors.friendlyBoss = { r, g, b } Aloft:UpdateNameplateText() end,
						},
						hostile =
						{
							type = 'color',
							name = L["Hostile Units"],
							desc = L["Sets the nameplate color for hostile units"],
							get = function() return unpack(Aloft.db.profile.nameplateText.colors.hostile) end,
							set = function(r, g, b) Aloft.db.profile.nameplateText.colors.hostile = { r, g, b } Aloft:UpdateNameplateText() end,
						},
						hostileBoss =
						{
							type = 'color',
							name = L["Hostile Boss"],
							desc = L["Sets the nameplate color for hostile boss units"],
							get = function() return unpack(Aloft.db.profile.nameplateText.colors.hostileBoss) end,
							set = function(r, g, b) Aloft.db.profile.nameplateText.colors.hostileBoss = { r, g, b } Aloft:UpdateNameplateText() end,
						},
						neutral =
						{
							type = 'color',
							name = L["Neutral Units"],
							desc = L["Sets the nameplate color for neutral units"],
							get = function() return unpack(Aloft.db.profile.nameplateText.colors.neutral) end,
							set = function(r, g, b) Aloft.db.profile.nameplateText.colors.neutral = { r, g, b } Aloft:UpdateNameplateText() end,
						},
						groupPet =
						{
							type = 'color',
							name = L["Group Pets"],
							desc = L["Sets the nameplate color for group pets"],
							get = function() return unpack(Aloft.db.profile.nameplateText.colors.groupPet) end,
							set = function(r, g, b) Aloft.db.profile.nameplateText.colors.groupPet = { r, g, b } Aloft:UpdateNameplateText() end,
						},
					}
				}
			},
		},

		healthBar =
		{
			type = 'group',
			name = L["Health Bar"],
			desc = L["Health Bar options"],
			args =
			{
				texture =
				{
					type = "text", 
					name = L["Texture"], 
					desc = L["Sets the health bar texture"],
					get = function() return Aloft.db.profile.healthBar.texture end,
					set = function(v) Aloft.db.profile.healthBar.texture = v Aloft:UpdateHealthBars() end,
					validate = SML_statusbar,
				},
				width =
				{
					type = 'range',
					name = L["Width"],
					desc = L["Sets the width of the health bar"],
					min = 50,
					max = 250,
					step = 1,
					get = function() return Aloft.db.profile.healthBar.width end,
					set = function(v) Aloft.db.profile.healthBar.width = v Aloft:UpdateHealthBarSize() end,
				},
				height =
				{
					type = 'range',
					name = L["Height"],
					desc = L["Sets the height of the health bar"],
					min = 4,
					max = 40,
					step = 1,
					get = function() return Aloft.db.profile.healthBar.height end,
					set = function(v) Aloft.db.profile.healthBar.height = v Aloft:UpdateHealthBarSize() end,
				},
				alpha =
				{
					type = 'range',
					name = L["Alpha"],
					desc = L["Sets the health bar alpha"],
					min = 0,
					max = 1.0,
					step = 0.05,
					get = function() return Aloft.db.profile.healthBar.alpha end,
					set = function(v) Aloft.db.profile.healthBar.alpha = v Aloft:UpdateHealthBars() end
				},
				colorByClass =
				{
					type = 'toggle',
					name = L["Color by Class"],
					desc = L["Sets the health bar color according to class. Requires Prat.PlayerNames enabled to show out of group colors"],
					get = function() return Aloft.db.profile.healthBar.colorByClass end,
					set = function(v) Aloft.db.profile.healthBar.colorByClass = v Aloft:UpdateHealthBars() end
				},
				groupOnly =
				{
					type = 'toggle',
					name = L["Group Only"],
					desc = L["Only colors group member's health bars by class"],
					disabled = function() return not Aloft.db.profile.healthBar.colorByClass end,
					get = function() return Aloft.db.profile.healthBar.groupOnly end,
					set = function(v) Aloft.db.profile.healthBar.groupOnly = v Aloft:UpdateHealthBars() end
				},
				colors =
				{
					type = 'group',
					name = L["Colors"],
					desc = L["Customize colors"],
					args =
					{
						friendlyPlayer =
						{
							type = 'color',
							name = L["Friendly Players"],
							desc = L["Sets the health bar color for friendly players"],
							get = function() return unpack(Aloft.db.profile.healthBar.colors.friendlyPlayer) end,
							set = function(r, g, b) Aloft.db.profile.healthBar.colors.friendlyPlayer = { r, g, b } Aloft:UpdateHealthBars() end
						},
						friendlyNPC =
						{
							type = 'color',
							name = L["Friendly NPCs"],
							desc = L["Sets the health bar color for friendly NPCs"],
							get = function() return unpack(Aloft.db.profile.healthBar.colors.friendlyNPC) end,
							set = function(r, g, b) Aloft.db.profile.healthBar.colors.friendlyNPC = { r, g, b } Aloft:UpdateHealthBars() end
						},
						friendlyBoss =
						{
							type = 'color',
							name = L["Friendly Boss"],
							desc = L["Sets the health bar color for friendly NPC Bosses"],
							get = function() return unpack(Aloft.db.profile.healthBar.colors.friendlyBoss) end,
							set = function(r, g, b) Aloft.db.profile.healthBar.colors.friendlyBoss = { r, g, b } Aloft:UpdateHealthBars() end
						},
						hostile =
						{
							type = 'color',
							name = L["Hostile Units"],
							desc = L["Sets the health bar color for hostile units"],
							get = function() return unpack(Aloft.db.profile.healthBar.colors.hostile) end,
							set = function(r, g, b) Aloft.db.profile.healthBar.colors.hostile = { r, g, b } Aloft:UpdateHealthBars() end
						},
						hostileBoss =
						{
							type = 'color',
							name = L["Hostile Boss"],
							desc = L["Sets the health bar color for hostile boss units"],
							get = function() return unpack(Aloft.db.profile.healthBar.colors.hostileBoss) end,
							set = function(r, g, b) Aloft.db.profile.healthBar.colors.hostileBoss = { r, g, b } Aloft:UpdateHealthBars() end
						},
						neutral =
						{
							type = 'color',
							name = L["Neutral Units"],
							desc = L["Sets the health bar color for neutral units"],
							get = function() return unpack(Aloft.db.profile.healthBar.colors.neutral) end,
							set = function(r, g, b) Aloft.db.profile.healthBar.colors.neutral = { r, g, b } Aloft:UpdateHealthBars() end
						},
						groupPet =
						{
							type = 'color',
							name = L["Group Pets"],
							desc = L["Sets the health bar color for group pets"],
							get = function() return unpack(Aloft.db.profile.healthBar.colors.groupPet) end,
							set = function(r, g, b) Aloft.db.profile.healthBar.colors.groupPet = { r, g, b } Aloft:UpdateHealthBars() end
						},
					}
				}
			},
		},

		healthText =
		{
			type = 'group',
			name = L["Health Text"],
			desc = L["Health text options"],
			args =
			{
				font =
				{
					type = "text", 
					name = L["Font"], 
					desc = L["Sets the font for health text"],
					get = function() return Aloft.db.profile.healthText.font end,
					set = function(v) Aloft.db.profile.healthText.font = v Aloft:UpdateHealthTexts() end,
					validate = SML_font,
				},
				fontSize =
				{
					type = 'range',
					name = L["Font Size"],
					desc = L["Sets the font height of the health text"],
					max = 16,
					min = 5,
					step = 1,
					get = function() return Aloft.db.profile.healthText.fontSize end,
					set = function(value) Aloft.db.profile.healthText.fontSize = value Aloft:UpdateHealthTexts() end
				},
				shadow =
				{
					type = 'toggle',
					name = L["Font Shadow"],
					desc = L["Show font shadow on health text"],
					get = function() return Aloft.db.profile.healthText.shadow end,
					set = function(v) Aloft.db.profile.healthText.shadow = v Aloft:UpdateHealthTexts() end
				},
				outline =
				{
					type = 'text',
					name = L["Outline"],
					desc = L["Sets the outline for health text"],
					get = function() return Aloft.db.profile.healthText.outline end,
					set = function(value) Aloft.db.profile.healthText.outline = value Aloft:UpdateHealthTexts() end,
					validate = {"None", "Normal", "Thick"},
				},
				mode =
				{
					type = 'text',
					name = L["Mode"],
					desc = L["Choose what to show for health text"],
					get = function() return Aloft.db.profile.healthText.mode end,
					set = function(value) Aloft.db.profile.healthText.mode = value Aloft:UpdateHealthTexts() end,
					validate = {"Hidden", "Percent", "Group Health", "Group Health Deficit", "Health"},
				},
				anchor = {
					type = "text", 
					name = L["Anchor"], 
					desc = L["Sets the anchor for the health text"],
					get = function() return Aloft.db.profile.healthText.point end,
					set = function(v) Aloft.db.profile.healthText.point = v Aloft:UpdateHealthTexts() end,
					validate = {"TOPLEFT", "TOP", "TOPRIGHT", "LEFT", "CENTER", "RIGHT", "BOTTOMLEFT", "BOTTOM", "BOTTOMRIGHT"},
				},
				anchorto = {
					type = "text", 
					name = L["Anchor To"], 
					desc = L["Sets the relative point on the health bar to anchor the health text"],
					get = function() return Aloft.db.profile.healthText.relativeToPoint end,
					set = function(v) Aloft.db.profile.healthText.relativeToPoint = v Aloft:UpdateHealthTexts() end,
					validate = {"TOPLEFT", "TOP", "TOPRIGHT", "LEFT", "CENTER", "RIGHT", "BOTTOMLEFT", "BOTTOM", "BOTTOMRIGHT"},
				},
				offsetX =
				{
					type = 'range',
					name = L["X Offset"],
					desc = L["X offset of the health text"],
					min = -32,
					max = 32,
					step = 1,
					get = function() return Aloft.db.profile.healthText.offsetX end,
					set = function(v) Aloft.db.profile.healthText.offsetX = v Aloft:UpdateHealthTexts() end
				},
				offsetY =
				{
					type = 'range',
					name = L["Y Offset"],
					desc = L["Y offset of the health text"],
					min = -32,
					max = 32,
					step = 1,
					get = function() return Aloft.db.profile.healthText.offsetY end,
					set = function(v) Aloft.db.profile.healthText.offsetY = v Aloft:UpdateHealthTexts() end
				},
				alpha =
				{
					type = 'range',
					name = L["Alpha"],
					desc = L["Sets the alpha of the health text"],
					min = 0,
					max = 1.0,
					step = 0.05,
					get = function() return Aloft.db.profile.healthText.alpha end,
					set = function(v) Aloft.db.profile.healthText.alpha = v Aloft:UpdateHealthTexts() end
				},
				color =
				{
					type = 'color',
					name = L["Color"],
					desc = L["Sets the health text color"],
					get = function() return unpack(Aloft.db.profile.healthText.color) end,
					set = function(r, g, b, a) Aloft.db.profile.healthText.color = { r, g, b, a } Aloft:UpdateHealthTexts() end,
				},
			},
		},

		levelText =
		{
			type = 'group',
			name = L["Level Text"],
			desc = L["Level text options"],
			args =
			{
				visible = 
				{
					type = 'toggle',
					name = L["Enable"],
					desc = L["Enable level text display on the nameplate"],
					get = function() return Aloft.db.profile.levelText.visible end,
					set = function(v) Aloft.db.profile.levelText.visible = v Aloft:UpdateLevelText() end
				},
				font =
				{
					type = "text", 
					name = L["Font"], 
					desc = L["Sets the font for level text"],
					get = function() return Aloft.db.profile.levelText.font end,
					set = function(v) Aloft.db.profile.levelText.font = v Aloft:UpdateLevelText() end,
					validate = SML_font,
				},
				fontSize =
				{
					type = 'range',
					name = L["Font Size"],
					desc = L["Sets the font height of the level text"],
					max = 16,
					min = 5,
					step = 1,
					get = function() return Aloft.db.profile.levelText.fontSize end,
					set = function(value) Aloft.db.profile.levelText.fontSize = value Aloft:UpdateLevelText() end
				},
				shadow =
				{
					type = 'toggle',
					name = L["Font Shadow"],
					desc = L["Show font shadow on level text"],
					get = function() return Aloft.db.profile.levelText.shadow end,
					set = function(v) Aloft.db.profile.levelText.shadow = v Aloft:UpdateLevelText() end
				},
				outline =
				{
					type = 'text',
					name = L["Outline"],
					desc = L["Sets the font outline of the level text"],
					get = function() return Aloft.db.profile.levelText.outline end,
					set = function(value) Aloft.db.profile.levelText.outline = value Aloft:UpdateLevelText() end,
					validate = {"None", "Normal", "Thick" },
				},
				anchor = {
					type = "text", 
					name = L["Anchor"], 
					desc = L["Sets the anchor for the level text"],
					get = function() return Aloft.db.profile.levelText.point end,
					set = function(v) Aloft.db.profile.levelText.point = v Aloft:UpdateLevelText() end,
					validate = {"TOPLEFT", "TOP", "TOPRIGHT", "LEFT", "CENTER", "RIGHT", "BOTTOMLEFT", "BOTTOM", "BOTTOMRIGHT"},
				},
				anchorto = {
					type = "text", 
					name = L["Anchor To"], 
					desc = L["Sets the relative point on the health bar to anchor the level text"],
					get = function() return Aloft.db.profile.levelText.relativeToPoint end,
					set = function(v) Aloft.db.profile.levelText.relativeToPoint = v Aloft:UpdateLevelText() end,
					validate = {"TOPLEFT", "TOP", "TOPRIGHT", "LEFT", "CENTER", "RIGHT", "BOTTOMLEFT", "BOTTOM", "BOTTOMRIGHT"},
				},
				offsetX =
				{
					type = 'range',
					name = L["X Offset"],
					desc = L["X offset of the level text"],
					min = -32,
					max = 32,
					step = 1,
					get = function() return Aloft.db.profile.levelText.offsetX end,
					set = function(v) Aloft.db.profile.levelText.offsetX = v Aloft:UpdateLevelText() end
				},
				offsetY =
				{
					type = 'range',
					name = L["Y Offset"],
					desc = L["Y offset of the level text"],
					min = -32,
					max = 32,
					step = 1,
					get = function() return Aloft.db.profile.levelText.offsetY end,
					set = function(v) Aloft.db.profile.levelText.offsetY = v Aloft:UpdateLevelText() end
				},
			},
		},

		overlay =
		{
			type = 'group',
			name = L["Overlay"],
			desc = L["Overlay options"],
			args =
			{
				visible =
				{
					type = 'toggle',
					name = L["Enable"],
					desc = L["Show an overlay on the full health bar"],
					get = function() return Aloft.db.profile.overlay.visible end,
					set = function(v) Aloft.db.profile.overlay.visible = v Aloft:UpdateOverlays() end
				},
				color =
				{
					type = 'color',
					name = L["Color"],
					desc = L["Sets the overlay color"],
					disabled  = function() return not Aloft.db.profile.overlay.visible end,
					get = function() return unpack(Aloft.db.profile.overlay.color) end,
					set = function(r, g, b, a) Aloft.db.profile.overlay.color = { r, g, b, a } Aloft:UpdateOverlays() end,
					hasAlpha = true
				},
				texture =
				{
					type = "text", 
					name = L["Texture"], 
					desc = L["Sets the overlay texture"],
					get = function() return Aloft.db.profile.overlay.texture end,
					set = function(v) Aloft.db.profile.overlay.texture = v Aloft:UpdateOverlays() end,
					validate = SML_statusbar,
				},
				horizontalPadding =
				{
					type = 'range',
					name = L["Horizontal Padding"],
					desc = L["Horizontal padding of the overlay texture compared to the the health bar"],
					min = 0,
					max = 8,
					step = 0.1,
					disabled = function() return Aloft.db.profile.overlay.emulateBackground end,
					get = function() return Aloft.db.profile.overlay.horizontalPadding end,
					set = function(v) Aloft.db.profile.overlay.horizontalPadding = v Aloft:UpdateOverlays() end
				},
				verticalPadding =
				{
					type = 'range',
					name = L["Vertical Padding"],
					desc = L["Vertical padding of the overlay texture compared to the the health bar"],
					min = 0,
					max = 8,
					step = 0.1,
					disabled = function() return Aloft.db.profile.overlay.emulateBackground end,
					get = function() return Aloft.db.profile.overlay.verticalPadding end,
					set = function(v) Aloft.db.profile.overlay.verticalPadding = v Aloft:UpdateOverlays() end
				},
				emulateBackground = 
				{
					type = 'toggle',
					name = L["Emulate Background"],
					desc = L["Dynamically adjust the position of the overlay texture to make it appear as a background to the health bar"],
					get = function() return Aloft.db.profile.overlay.emulateBackground end,
					set = function(v) Aloft.db.profile.overlay.emulateBackground = v Aloft:UpdateOverlays() end
				},
			},
		},
	
		highlight =
		{
			type = 'group',
			name = L["Highlight"],
			desc = L["Mouseover highlight options"],
			args =
			{
				color =
				{
					type = 'color',
					name = L["Color"],
					desc = L["Sets the highlight color"],
					get = function() return unpack(Aloft.db.profile.highlight.color) end,
					set = function(r, g, b, a) Aloft.db.profile.highlight.color = { r, g, b, a } Aloft:UpdateHighlights() end,
					hasAlpha = true
				},
				texture =
				{
					type = "text", 
					name = L["Texture"], 
					desc = L["Sets the highlight texture"],
					get = function() return Aloft.db.profile.highlight.texture end,
					set = function(v) Aloft.db.profile.highlight.texture = v Aloft:UpdateHighlights() end,
					validate = SML_statusbar,
				},
				mode =
				{
					type = "text",
					name = L["Blend Mode"],
					desc = L["Sets the blend mode for the highlight texture"],
					get = function() return Aloft.db.profile.highlight.blendMode end,
					set = function(v) Aloft.db.profile.highlight.blendMode = v Aloft:UpdateHighlights() end,
					validate = { "BLEND", "ADD" },
				},
			},
		},
	
		raidIcon =
		{
			type = 'group',
			name = L["Raid Icon"],
			desc = L["Raid icon placement options"],
			args =
			{
				visible = 
				{
					type = 'toggle',
					name = L["Enable"],
					desc = L["Enable raid icon display on the nameplate"],
					get = function() return Aloft.db.profile.raidIcon.visible end,
					set = function(v) Aloft.db.profile.raidIcon.visible = v Aloft:UpdateRaidIcons() end
				},
				anchor = {
					type = "text", 
					name = L["Anchor"], 
					desc = L["Sets the anchor for the raid icon"],
					get = function() return Aloft.db.profile.raidIcon.point end,
					set = function(v) Aloft.db.profile.raidIcon.point = v Aloft:UpdateRaidIcons() end,
					validate = {"TOPLEFT", "TOP", "TOPRIGHT", "LEFT", "CENTER", "RIGHT", "BOTTOMLEFT", "BOTTOM", "BOTTOMRIGHT"},
				},
				anchorto = {
					type = "text", 
					name = L["Anchor To"], 
					desc = L["Sets the relative point on the health bar to anchor the raid icon"],
					get = function() return Aloft.db.profile.raidIcon.relativeToPoint end,
					set = function(v) Aloft.db.profile.raidIcon.relativeToPoint = v Aloft:UpdateRaidIcons() end,
					validate = {"TOPLEFT", "TOP", "TOPRIGHT", "LEFT", "CENTER", "RIGHT", "BOTTOMLEFT", "BOTTOM", "BOTTOMRIGHT"},
				},
				size =
				{
					type = 'range',
					name = L["Size"],
					desc = L["Size in pixels of the raid icon"],
					min = 4,
					max = 32,
					step = 1,
					get = function() return Aloft.db.profile.raidIcon.size end,
					set = function(v) Aloft.db.profile.raidIcon.size = v Aloft:UpdateRaidIcons() end
				},
				offsetX =
				{
					type = 'range',
					name = L["X Offset"],
					desc = L["X offset of the raid icon"],
					min = -32,
					max = 32,
					step = 1,
					get = function() return Aloft.db.profile.raidIcon.offsetX end,
					set = function(v) Aloft.db.profile.raidIcon.offsetX = v Aloft:UpdateRaidIcons() end
				},
				offsetY =
				{
					type = 'range',
					name = L["Y Offset"],
					desc = L["Y offset of the raid icon"],
					min = -32,
					max = 32,
					step = 1,
					get = function() return Aloft.db.profile.raidIcon.offsetY end,
					set = function(v) Aloft.db.profile.raidIcon.offsetY = v Aloft:UpdateRaidIcons() end
				},
				alpha =
				{
					type = 'range',
					name = L["Alpha"],
					desc = L["Sets the raid icon alpha"],
					min = 0,
					max = 1.0,
					step = 0.05,
					get = function() return Aloft.db.profile.raidIcon.alpha end,
					set = function(v) Aloft.db.profile.raidIcon.alpha = v Aloft:UpdateRaidIcons() end
				},
			},
		},

		bossIcon =
		{
			type = 'group',
			name = L["Boss Icon"],
			desc = L["Boss icon placement options"],
			args =
			{
				visible = 
				{
					type = 'toggle',
					name = L["Enable"],
					desc = L["Enable boss icon display on the nameplate"],
					get = function() return Aloft.db.profile.bossIcon.visible end,
					set = function(v) Aloft.db.profile.bossIcon.visible = v Aloft:UpdateBossIcons() end
				},
				anchor = {
					type = "text", 
					name = L["Anchor"], 
					desc = L["Sets the anchor for the boss icon"],
					get = function() return Aloft.db.profile.bossIcon.point end,
					set = function(v) Aloft.db.profile.bossIcon.point = v Aloft:UpdateBossIcons() end,
					validate = {"TOPLEFT", "TOP", "TOPRIGHT", "LEFT", "CENTER", "RIGHT", "BOTTOMLEFT", "BOTTOM", "BOTTOMRIGHT"},
				},
				anchorto = {
					type = "text", 
					name = L["Anchor To"], 
					desc = L["Sets the relative point on the health bar to anchor the boss icon"],
					get = function() return Aloft.db.profile.bossIcon.relativeToPoint end,
					set = function(v) Aloft.db.profile.bossIcon.relativeToPoint = v Aloft:UpdateBossIcons() end,
					validate = {"TOPLEFT", "TOP", "TOPRIGHT", "LEFT", "CENTER", "RIGHT", "BOTTOMLEFT", "BOTTOM", "BOTTOMRIGHT"},
				},
				size =
				{
					type = 'range',
					name = L["Size"],
					desc = L["Size in pixels of the boss icon"],
					min = 4,
					max = 32,
					step = 1,
					get = function() return Aloft.db.profile.bossIcon.size end,
					set = function(v) Aloft.db.profile.bossIcon.size = v Aloft:UpdateBossIcons() end
				},
				offsetX =
				{
					type = 'range',
					name = L["X Offset"],
					desc = L["X offset of the boss icon"],
					min = -32,
					max = 32,
					step = 1,
					get = function() return Aloft.db.profile.bossIcon.offsetX end,
					set = function(v) Aloft.db.profile.bossIcon.offsetX = v Aloft:UpdateBossIcons() end
				},
				offsetY =
				{
					type = 'range',
					name = L["Y Offset"],
					desc = L["Y offset of the boss icon"],
					min = -32,
					max = 32,
					step = 1,
					get = function() return Aloft.db.profile.bossIcon.offsetY end,
					set = function(v) Aloft.db.profile.bossIcon.offsetY = v Aloft:UpdateBossIcons() end
				},
				alpha =
				{
					type = 'range',
					name = L["Alpha"],
					desc = L["Sets the boss icon alpha"],
					min = 0,
					max = 1.0,
					step = 0.05,
					get = function() return Aloft.db.profile.bossIcon.alpha end,
					set = function(v) Aloft.db.profile.bossIcon.alpha = v Aloft:UpdateBossIcons() end
				},
			},
		},

		spellIcon =
		{
			type = 'group',
			name = L["Spell Icon"],
			desc = L["Spell icon placement options"],
			args =
			{
				visible = 
				{
					type = 'toggle',
					name = L["Enable"],
					desc = L["Enable spell icon display on the nameplate"],
					get = function() return Aloft.db.profile.spellIcon.visible end,
					set = function(v) Aloft.db.profile.spellIcon.visible = v Aloft:UpdateSpellIcons() end
				},
				anchor = {
					type = "text", 
					name = L["Anchor"], 
					desc = L["Sets the anchor for the spell icon"],
					get = function() return Aloft.db.profile.spellIcon.point end,
					set = function(v) Aloft.db.profile.spellIcon.point = v Aloft:UpdateSpellIcons() end,
					validate = {"TOPLEFT", "TOP", "TOPRIGHT", "LEFT", "CENTER", "RIGHT", "BOTTOMLEFT", "BOTTOM", "BOTTOMRIGHT"},
				},
				anchorto = {
					type = "text", 
					name = L["Anchor To"], 
					desc = L["Sets the relative point on the cast bar to anchor the spell icon"],
					get = function() return Aloft.db.profile.spellIcon.relativeToPoint end,
					set = function(v) Aloft.db.profile.spellIcon.relativeToPoint = v Aloft:UpdateSpellIcons() end,
					validate = {"TOPLEFT", "TOP", "TOPRIGHT", "LEFT", "CENTER", "RIGHT", "BOTTOMLEFT", "BOTTOM", "BOTTOMRIGHT"},
				},
				size =
				{
					type = 'range',
					name = L["Size"],
					desc = L["Size in pixels of the spell icon"],
					min = 4,
					max = 32,
					step = 1,
					get = function() return Aloft.db.profile.spellIcon.size end,
					set = function(v) Aloft.db.profile.spellIcon.size = v Aloft:UpdateSpellIcons() end
				},
				offsetX =
				{
					type = 'range',
					name = L["X Offset"],
					desc = L["X offset of the spell icon"],
					min = -32,
					max = 32,
					step = 1,
					get = function() return Aloft.db.profile.spellIcon.offsetX end,
					set = function(v) Aloft.db.profile.spellIcon.offsetX = v Aloft:UpdateSpellIcons() end
				},
				offsetY =
				{
					type = 'range',
					name = L["Y Offset"],
					desc = L["Y offset of the spell icon"],
					min = -32,
					max = 32,
					step = 1,
					get = function() return Aloft.db.profile.spellIcon.offsetY end,
					set = function(v) Aloft.db.profile.spellIcon.offsetY = v Aloft:UpdateSpellIcons() end
				},
			},
		},

		castBarOverlay =
		{
			type = 'group',
			name = L["Cast Bar Overlay"],
			desc = L["Cast bar overlay options"],
			args =
			{
				visible =
				{
					type = 'toggle',
					name = L["Enable"],
					desc = L["Show an overlay on the full cast bar"],
					get = function() return Aloft.db.profile.castBarOverlay.visible end,
					set = function(v) Aloft.db.profile.castBarOverlay.visible = v Aloft:UpdateCastBarOverlays() end
				},
				color =
				{
					type = 'color',
					name = L["Color"],
					desc = L["Sets the cast bar overlay color"],
					get = function() return unpack(Aloft.db.profile.castBarOverlay.color) end,
					set = function(r, g, b, a) Aloft.db.profile.castBarOverlay.color = { r, g, b, a } Aloft:UpdateCastBarOverlays() end,
					hasAlpha = true
				},
				texture =
				{
					type = "text", 
					name = L["Texture"], 
					desc = L["Sets the cast bar overlay texture"],
					get = function() return Aloft.db.profile.castBarOverlay.texture end,
					set = function(v) Aloft.db.profile.castBarOverlay.texture = v Aloft:UpdateCastBarOverlays() end,
					validate = SML_statusbar,
				},
				horizontalPadding =
				{
					type = 'range',
					name = L["Horizontal Padding"],
					desc = L["Horizontal padding of the overlay texture compared to the the cast bar"],
					min = 0,
					max = 8,
					step = 0.1,
					disabled = function() return Aloft.db.profile.castBarOverlay.emulateBackground end,
					get = function() return Aloft.db.profile.castBarOverlay.horizontalPadding end,
					set = function(v) Aloft.db.profile.castBarOverlay.horizontalPadding = v Aloft:UpdateCastBarOverlays() end
				},
				verticalPadding =
				{
					type = 'range',
					name = L["Vertical Padding"],
					desc = L["Vertical padding of the overlay texture compared to the the cast bar"],
					min = 0,
					max = 8,
					step = 0.1,
					disabled = function() return Aloft.db.profile.castBarOverlay.emulateBackground end,
					get = function() return Aloft.db.profile.castBarOverlay.verticalPadding end,
					set = function(v) Aloft.db.profile.castBarOverlay.verticalPadding = v Aloft:UpdateCastBarOverlays() end
				},
				emulateBackground = 
				{
					type = 'toggle',
					name = L["Emulate Background"],
					desc = L["Dynamically adjust the position of the cast bar overlay texture to make it appear as a background to the cast bar"],
					get = function() return Aloft.db.profile.castBarOverlay.emulateBackground end,
					set = function(v) Aloft.db.profile.castBarOverlay.emulateBackground = v Aloft:UpdateCastBarOverlays() end
				},
			},
		},
	
		castBar =
		{
			type = 'group',
			name = L["Cast Bar"],
			desc = L["Cast bar options"],
			args =
			{
				visible =
				{
					type = 'toggle',
					name = L["Enable"],
					desc = L["Show cast bars"],
					get = function() return GetCVar("ShowVKeyCastbar") == "1" end,
					set = function(v) SetCVar("ShowVKeyCastbar", v and "1" or "0") end
				},
				position =
				{
					type = 'group',
					name = L["Position"],
					desc = L["Adjust cast bar position"],
					args =
					{
						left =
						{
							type = 'range',
							name = L["Left Offset"],
							desc = L["Sets the offset of the left of the cast bar"],
							min = -32,
							max = 32,
							step = 1,
							get = function() return Aloft.db.profile.castBar.offsets.left end,
							set = function(v) Aloft.db.profile.castBar.offsets.left = v Aloft:UpdateCastBars() end
						},
						right =
						{
							type = 'range',
							name = L["Right Offset"],
							desc = L["Sets the offset of the right of the cast bar"],
							min = -32,
							max = 32,
							step = 1,
							get = function() return Aloft.db.profile.castBar.offsets.right end,
							set = function(v) Aloft.db.profile.castBar.offsets.right = v Aloft:UpdateCastBars() end
						},
						vertical =
						{
							type = 'range',
							name = L["Vertical Offset"],
							desc = L["Sets the vertical offset of the cast bar"],
							min = -32,
							max = 32,
							step = 1,
							get = function() return Aloft.db.profile.castBar.offsets.vertical end,
							set = function(v) Aloft.db.profile.castBar.offsets.vertical = v Aloft:UpdateCastBars() end
						},
					},
				},
				height =
				{
					type = 'range',
					name = L["Height"],
					desc = L["Sets the height of the cast bar"],
					min = 5,
					max = 32,
					step = 1,
					get = function() return Aloft.db.profile.castBar.height end,
					set = function(v) Aloft.db.profile.castBar.height = v Aloft:UpdateCastBars() end
				},
				texture =
				{
					type = "text", 
					name = L["Texture"], 
					desc = L["Sets the cast bar texture"],
					get = function() return Aloft.db.profile.castBar.texture end,
					set = function(v) Aloft.db.profile.castBar.texture = v Aloft:UpdateCastBars() end,
					validate = SML_statusbar,
				},
			},
		},
		
		castBarText =
		{
			type = 'group',
			name = L["Cast Bar Text"],
			desc = L["Cast bar text options"],
			args =
			{
				visible =
				{
					type = 'toggle',
					name = L["Enable"],
					desc = L["Show cast bar text"],
					get = function() return Aloft.db.profile.castBarText.visible end,
					set = function(v) Aloft.db.profile.castBarText.visible = v Aloft:UpdateCastBarText() end
				},
				font =
				{
					type = "text", 
					name = L["Font"], 
					desc = L["Sets the font for cast bar text"],
					get = function() return Aloft.db.profile.castBarText.font end,
					set = function(v) Aloft.db.profile.castBarText.font = v Aloft:UpdateCastBarText() end,
					validate = SML_font,
				},
				fontSize =
				{
					type = 'range',
					name = L["Font Size"],
					desc = L["Sets the font height of the cast bar text"],
					max = 16,
					min = 5,
					step = 1,
					get = function() return Aloft.db.profile.castBarText.fontSize end,
					set = function(value) Aloft.db.profile.castBarText.fontSize = value Aloft:UpdateCastBarText() end
				},
				shadow =
				{
					type = 'toggle',
					name = L["Font Shadow"],
					desc = L["Show font shadow on cast bar text"],
					get = function() return Aloft.db.profile.castBarText.shadow end,
					set = function(v) Aloft.db.profile.castBarText.shadow = v Aloft:UpdateCastBarText() end
				},
				outline =
				{
					type = 'text',
					name = L["Outline"],
					desc = L["Sets the outline for cast bar text"],
					get = function() return Aloft.db.profile.castBarText.outline end,
					set = function(value) Aloft.db.profile.castBarText.outline = value Aloft:UpdateCastBarText() end,
					validate = {"None", "Normal", "Thick"},
				},
				alignment =
				{
					type = 'text',
					name = L["Alignment"],
					desc = L["Sets the alignment of the cast bar text"],
					get = function() return Aloft.db.profile.castBarText.alignment end,
					set = function(value) Aloft.db.profile.castBarText.alignment = value Aloft:UpdateCastBarText() end,
					validate = {"LEFT", "CENTER", "RIGHT" },
				},
				outline =
				{
					type = 'text',
					name = L["Outline"],
					desc = L["Sets the font outline for cast bar text"],
					get = function() return Aloft.db.profile.castBarText.outline end,
					set = function(value) Aloft.db.profile.castBarText.outline = value Aloft:UpdateCastBarText() end,
					validate = {"None", "Normal", "Thick" },
				},
				position =
				{
					type = 'group',
					name = L["Position"],
					desc = L["Adjust cast bar text position"],
					args =
					{
						left =
						{
							type = 'range',
							name = L["Left Offset"],
							desc = L["Sets the offset of the left of the text"],
							min = -32,
							max = 32,
							step = 1,
							get = function() return Aloft.db.profile.castBarText.offsets.left end,
							set = function(v) Aloft.db.profile.castBarText.offsets.left = v Aloft:UpdateCastBarText() end
						},
						right =
						{
							type = 'range',
							name = L["Right Offset"],
							desc = L["Sets the offset of the right of the text"],
							min = -32,
							max = 32,
							step = 1,
							get = function() return Aloft.db.profile.castBarText.offsets.right end,
							set = function(v) Aloft.db.profile.castBarText.offsets.right = v Aloft:UpdateCastBarText() end
						},
						vertical =
						{
							type = 'range',
							name = L["Vertical Offset"],
							desc = L["Sets the vertical offset of the text"],
							min = -32,
							max = 32,
							step = 1,
							get = function() return Aloft.db.profile.castBarText.offsets.vertical end,
							set = function(v) Aloft.db.profile.castBarText.offsets.vertical = v Aloft:UpdateCastBarText() end
						},
					},
				},
				color =
				{
					type = 'color',
					name = L["Color"],
					desc = L["Sets the cast bar text color"],
					get = function() return unpack(Aloft.db.profile.castBarText.color) end,
					set = function(r, g, b, a) Aloft.db.profile.castBarText.color = { r, g, b, a } Aloft:UpdateCastBarText() end,
					hasAlpha = true
				},
			},
		},

		castBarTimeText =
		{
			type = 'group',
			name = L["Cast Bar Time Text"],
			desc = L["Cast bar time text options"],
			args =
			{
				visible =
				{
					type = 'toggle',
					name = L["Enable"],
					desc = L["Show cast bar time text"],
					get = function() return Aloft.db.profile.castBarTimeText.visible end,
					set = function(v) Aloft.db.profile.castBarTimeText.visible = v Aloft:UpdateCastBarTimeText() end
				},
				font =
				{
					type = "text", 
					name = L["Font"], 
					desc = L["Sets the font for cast bar time text"],
					get = function() return Aloft.db.profile.castBarTimeText.font end,
					set = function(v) Aloft.db.profile.castBarTimeText.font = v Aloft:UpdateCastBarTimeText() end,
					validate = SML_font,
				},
				fontSize =
				{
					type = 'range',
					name = L["Font Size"],
					desc = L["Sets the font height of the cast bar time text"],
					max = 16,
					min = 5,
					step = 1,
					get = function() return Aloft.db.profile.castBarTimeText.fontSize end,
					set = function(value) Aloft.db.profile.castBarTimeText.fontSize = value Aloft:UpdateCastBarTimeText() end
				},
				shadow =
				{
					type = 'toggle',
					name = L["Font Shadow"],
					desc = L["Show font shadow on cast bar time text"],
					get = function() return Aloft.db.profile.castBarTimeText.shadow end,
					set = function(v) Aloft.db.profile.castBarTimeText.shadow = v Aloft:UpdateCastBarTimeText() end
				},
				outline =
				{
					type = 'text',
					name = L["Outline"],
					desc = L["Sets the outline for cast bar time text"],
					get = function() return Aloft.db.profile.castBarTimeText.outline end,
					set = function(value) Aloft.db.profile.castBarTimeText.outline = value Aloft:UpdateCastBarTimeText() end,
					validate = {"None", "Normal", "Thick"},
				},
				alignment =
				{
					type = 'text',
					name = L["Alignment"],
					desc = L["Sets the alignment of the cast bar time text"],
					get = function() return Aloft.db.profile.castBarTimeText.alignment end,
					set = function(value) Aloft.db.profile.castBarTimeText.alignment = value Aloft:UpdateCastBarTimeText() end,
					validate = {"LEFT", "CENTER", "RIGHT" },
				},
				outline =
				{
					type = 'text',
					name = L["Outline"],
					desc = L["Sets the font outline for cast bar time text"],
					get = function() return Aloft.db.profile.castBarTimeText.outline end,
					set = function(value) Aloft.db.profile.castBarTimeText.outline = value Aloft:UpdateCastBarTimeText() end,
					validate = {"None", "Normal", "Thick" },
				},
				position =
				{
					type = 'group',
					name = L["Position"],
					desc = L["Adjust cast bar time text position"],
					args =
					{
						left =
						{
							type = 'range',
							name = L["Left Offset"],
							desc = L["Sets the offset of the left of the text"],
							min = -32,
							max = 32,
							step = 1,
							get = function() return Aloft.db.profile.castBarTimeText.offsets.left end,
							set = function(v) Aloft.db.profile.castBarTimeText.offsets.left = v Aloft:UpdateCastBarTimeText() end
						},
						right =
						{
							type = 'range',
							name = L["Right Offset"],
							desc = L["Sets the offset of the right of the text"],
							min = -32,
							max = 32,
							step = 1,
							get = function() return Aloft.db.profile.castBarTimeText.offsets.right end,
							set = function(v) Aloft.db.profile.castBarTimeText.offsets.right = v Aloft:UpdateCastBarTimeText() end
						},
						vertical =
						{
							type = 'range',
							name = L["Vertical Offset"],
							desc = L["Sets the vertical offset of the text"],
							min = -32,
							max = 32,
							step = 1,
							get = function() return Aloft.db.profile.castBarTimeText.offsets.vertical end,
							set = function(v) Aloft.db.profile.castBarTimeText.offsets.vertical = v Aloft:UpdateCastBarTimeText() end
						},
					},
				},
				color =
				{
					type = 'color',
					name = L["Color"],
					desc = L["Sets the cast bar time text color"],
					get = function() return unpack(Aloft.db.profile.castBarTimeText.color) end,
					set = function(r, g, b, a) Aloft.db.profile.castBarTimeText.color = { r, g, b, a } Aloft:UpdateCastBarTimeText() end,
					hasAlpha = true
				},
			},
		},
	},
}

Aloft:RegisterChatCommand({"/aloft"}, Aloft.OnMenuRequest)

-----------------------------------------------------------------------------
